    const sample = [
      {
        Title: 'Avatar',
        LifeTimeGross: 284724,
       
      },
      {
        Title: 'Avengers',
        LifeTimeGross: 279750,
        
      },
      {
        Title: 'Titanic',
        LifeTimeGross: 220164,
      },
      {
        Title: 'RED',
        LifeTimeGross: 206952,
      },
      {
        Title: 'War',
        LifeTimeGross: 204835,
      },
      {
        Title: 'IT',
        LifeTimeGross: 183144,
      },
      {
        Title: 'YOU',
        LifeTimeGross: 167051,
      },
      {
        Title: 'BEN',
        LifeTimeGross: 166289,
      },
      {
        Title: 'UP',
        LifeTimeGross: 151881,
      },
      {
        Title: 'Furious',
        LifeTimeGross: 151534,
      }
    ];

    const svg = d3.select('svg');
    const svgContainer = d3.select('#container');
    
    const margin = 300;
    const width = 1000 - 2 * margin;
    const height = 10;

    const chart = svg.append('g')
      .attr('transform', `translate(${margin}, ${margin})`);

    const xScale = d3.scaleBand()
      .range([0, width])
      .domain(sample.map((s) => s.Title))
      .padding(0.3)
    
    const yScale = d3.scaleLinear()
      .range([height, 0])
      .domain(sample.map((s) => s.LifeTimeGross));

    // vertical grid lines
    // const makeXLines = () => d3.axisBottom()
    //   .scale(xScale)

    const makeYLines = () => d3.axisLeft()
      .scale(yScale)

    chart.append('g')
      .attr('transform', `translate(0, ${height})`)
      .call(d3.axisBottom(xScale));

    chart.append('g')
      .call(d3.axisLeft(yScale));


    chart.append('g')
      .attr('class', 'grid')
      .call(makeYLines()
        .tickSize(-width, 0, 0)
        .tickFormat('')
      )

    const barGroups = chart.selectAll()
      .data(sample)
      .enter()
      .append('g')

    barGroups
      .append('rect')
      .attr('class', 'bar')
      .attr('x', (g) => xScale(g.Title))
      .attr('y', (g) => yScale(g.LifeTimeGross))
      .attr('height', (g) => height - yScale(g.LifeTimeGross))
      .attr('width', xScale.bandwidth())
      .on('mouseenter', function (actual, i) {
        d3.selectAll('.LifeTimeGross')
          .attr('opacity', 0)

        d3.select(this)
          .transition()
          .duration(300)
          .attr('opacity', 0.6)
          .attr('x', (a) => xScale(a.Title) - 5)
          .attr('width', xScale.bandwidth() + 10)

        const y = yScale(actual.LifeTimeGross)

        line = chart.append('line')
          .attr('id', 'limit')
          .attr('x1', 0)
          .attr('y1', y)
          .attr('x2', width)
          .attr('y2', y)

        barGroups.append('text')
          .attr('class', 'divergence')
          .attr('x', (a) => xScale(a.Title) + xScale.bandwidth() / 2)
          .attr('y', (a) => yScale(a.LifeTimeGross) + 30)
          .attr('fill', 'white')
          .attr('text-anchor', 'middle')
          .text((a, idx) => {
            const divergence = (a.LifeTimeGross - actual.LifeTimeGross).toFixed(1)
            
            let text = ''
            if (divergence > 0) text += '+'
            text += `${divergence}%`

            return idx !== i ? text : '';
          })

      })
      .on('mouseleave', function () {
        d3.selectAll('.LifeTimeGross')
          .attr('opacity', 1)

        d3.select(this)
          .transition()
          .duration(300)
          .attr('opacity', 1)
          .attr('x', (a) => xScale(a.Title))
          .attr('width', xScale.bandwidth())

        chart.selectAll('#limit').remove()
        chart.selectAll('.divergence').remove()
      })

    
    svg
      .append('text')
      .attr('class', 'label')
      .attr('x', -(height / 2) - margin)
      .attr('y', margin / 2.4)
      .attr('transform', 'rotate(-90)')
      .attr('text-anchor', 'middle')
      .text('Life time gross')

    svg.append('text')
      .attr('class', 'label')
      .attr('x', width / 2 + margin)
      .attr('y', 400)
      .attr('text-anchor', 'middle')
      .text('Titles')

    svg.append('text')
      .attr('class', 'title')
      .attr('x', width / 2 + margin)
      .attr('y', 40)
      .attr('text-anchor', 'middle')
      .text('Movies with respect to Life time gross')

   
  